#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-LR5vzIRZfcsL6T7RCwbyI5
key:                  persistent-test-2.13.1.3-LR5vzIRZfcsL6T7RCwbyI5
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  816c94dd33b0f9679fe35d0e44eccbfe
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-LR5vzIRZfcsL6T7RCwbyI5
depends:
    HUnit-1.6.2.0-3Gay08i9BeaLLyAIj783Ta
    QuickCheck-2.15.0.1-JreQmzbtNzG6Tfv3OFDtCd
    aeson-2.2.2.0-EED32RMVwDLAiFjSZ5pcFd base-4.18.2.1
    blaze-html-0.9.2.0-1lij6LgarWNIKE1NijtW1T bytestring-0.11.5.3
    conduit-1.3.6.1-JUYzY4vWR84IgzQpUbwiHB containers-0.6.7
    exceptions-0.10.7 hspec-2.11.7-6F1XmFUfp0F63qjezwwd3i
    hspec-expectations-0.8.4-BLvTq6ofDY2H3t5iUbJZ2w
    http-api-data-0.6.1-IgebMWwwxGG6Yff4RfOCfK
    monad-control-1.0.3.1-8wPa0oMkCWR7jw1sOTWw8m
    monad-logger-0.3.42-FSDr4IiUnTw6BIwJVBXY8D mtl-2.3.1
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    persistent-2.14.6.0-6nrGPweB5ScKrBBlwGtOxz
    quickcheck-instances-0.3.33-B2H49aVEJo13u5bpSFpdQW
    random-1.2.1.3-EfuxxTSFZVsDtv0C5Jgv69
    resourcet-1.2.6-etI90KJ6NDGooz2sPxaH4 text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-base-0.4.6.1-GqSX9ijaX57Je8pYGIG6bu
    unliftio-0.2.25.1-7e6qkdoKuwT8IE1NGOZn2K
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-9xqafn4Eq4w4BZS2LI6Zwa

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

